summaryrefslogtreecommitdiff
path: root/src/defines.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/defines.h')
-rw-r--r--src/defines.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/defines.h b/src/defines.h
index 90896f81..0c0f95f9 100644
--- a/src/defines.h
+++ b/src/defines.h
@@ -95,10 +95,9 @@ const unsigned int MAX_CLIENTS = 1024,
// Screen Related
/**
* Determine the area in which a character
* can hear another one speak
*/
- AROUND_AREA_IN_TILES = 10;
+ AROUND_AREA = 320;
/**
@@ -150,7 +149,8 @@ enum {
GPMSG_BEING_ENTER = 0x0200, // B type, L being id
// player: S name, B hair style, B hair color, B gender
GPMSG_BEING_LEAVE = 0x0201, // B type, L being id
- PGMSG_WALK = 0x0260, // L*2 destination
+ PGMSG_WALK = 0x0260, // W*2 destination
+ GPMSG_BEINGS_MOVE = 0x0280, // { L being id, W*2 position, W*2 destination }*
PGMSG_SAY = 0x02A0, // S text
GPMSG_SAY = 0x02A1, // S being, S text
PGMSG_USE_ITEM = 0x0300, // L item id
@@ -95,10 +95,9 @@ const unsigned int MAX_CLIENTS = 1024,
// Screen Related
/**
- * Determine the area in which a character
- * can hear another one speak
+ * Determine the area in which a character is aware of other beings
*/